@@ -30,7 +30,7 @@ class Printing:
 
             if os.path.isdir(text_input):
                 # if input is a folder, add a filename column
-                table.add_column("Filename", overflow="fold")
+                table.add_column("File", overflow="fold")
 
             for key, value in text["Regexes"].items():
                 for i in value:
@@ -39,7 +39,7 @@ class Printing:
                     description = None
                     filename = key
 
-                    if "URL" in i["Regex Pattern"]:
+                    if "URL" in i["Regex Pattern"] and i["Regex Pattern"]["URL"]:
                         description = (
                             "Click here to analyse in the browser\n"
                             + i["Regex Pattern"]["URL"]
